@@ -9,6 +9,7 @@ def condition_by_between(filters: list, model, column, start_value, end_value):
 def condition_by_in(filters: list, model, column, value):
     _filter = None
     if value and isinstance(value, list):
+        value = [_ for _ in value if _]
         _filter = getattr(model, column).in_(value)
         filters.append(_filter)
     return _filter
@@ -30,6 +31,14 @@ def condition_by_like(filters: list, model, column, value, position: str = "LR")
     return _filter
 
 
+def condition_by_regex(filters: list, model, column, value):
+    _filter = None
+    if value:
+        _filter = getattr(model, column).like(value)
+        filters.append(_filter)
+    return _filter
+
+
 def condition_by_not_in(filters: list, model, column, value):
     _filter = None
     if value is not None:
@@ -119,6 +128,8 @@ def condition_by_relation(filters: list, model, _column, _relation, _value, _end
         condition_by_in(filters, model, _column, _value)
     elif _relation == "like":
         condition_by_like(filters, model, _column, _value, _position)
+    elif _relation == "regex" or _relation == "re":
+        condition_by_regex(filters, model, _column, _value)
     elif _relation == "between":
         condition_by_between(filters, model, _column, _value, _end_value)
     elif _relation == "not in" or _relation == "ni":
